"use client"
import { CheckItemIconState, CheckItemType } from "@/types/CheckItem"
import { Icon } from "@iconify/react/dist/iconify.js"
import { useQuery } from "@tanstack/react-query"

type CheckItemProps = CheckItemType

const icon = {
  ok: (
    <Icon
      icon='material-symbols:check-circle-outline-rounded'
      className='stroke-1 text-success h-6 w-6 shrink-0'
    />
  ),
  loading: <span className='loading loading-spinner loading-xs'></span>,
  info: (
    <Icon
      icon='material-symbols:info-outline'
      className='stroke-1 text-info h-6 w-6 shrink-0'
    />
  ),
  error: (
    <Icon
      icon='material-symbols:error-outline'
      className='stroke-1 text-error h-6 w-6 shrink-0'
    />
  ),
}

export default function CheckItem({
  id,
  name,
  fetcher,
  content,
}: CheckItemProps) {
  const { data, error, isLoading } = useQuery({
    queryKey: [id],
    queryFn: fetcher,
  })

  return (
    <>
      <div role='alert' className='alert'>
        {error
          ? icon["error"]
          : isLoading
          ? icon["loading"]
          : data != undefined
          ? icon[content(data).state ?? "ok"]
          : null}

        <div>
          <span className='mr-4'>
            <b>{name}</b>
          </span>

          <span>
            {data != undefined
              ? content(data).text
              : error != null
              ? `无法获取: ${error.name}`
              : null}
          </span>
        </div>
      </div>
    </>
  )
}
